<?php

namespace Litecms\Property\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Property\Actions\ListingCategoryAction;
use Litecms\Property\Http\Requests\ListingCategoryActionRequest;
use Litecms\Property\Http\Resources\ListingCategoryResource;
use Litecms\Property\Models\ListingCategory;

/**
 * Admin web controller class.
 */
class ListingCategoryActionController extends BaseController
{

    /**
     * Action controller function for listing_category.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ListingCategoryActionRequest $request, ListingCategory $listing_category, $action)
    {
        try {
            $request = $request->all();
            $listing_category = ListingCategoryAction::run($action, $listing_category, $request);

            $data = new ListingCategoryResource($listing_category);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('property::listing_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('property/listing_category/' . $listing_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/listing_category/' . $listing_category->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
