<?php

namespace Litecms\Property\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Property\Forms\ListingCategory as ListingCategoryForm;
use Litecms\Property\Http\Requests\ListingCategoryResourceRequest;
use Litecms\Property\Http\Resources\ListingCategoryResource;
use Litecms\Property\Http\Resources\ListingCategoriesCollection;
use Litecms\Property\Models\ListingCategory;
use Litecms\Property\Actions\ListingCategoryAction;
use Litecms\Property\Actions\ListingCategoryActions;


/**
 * Resource controller class for listing_category.
 */
class ListingCategoryResourceController extends BaseController
{

    /**
     * Initialize listing_category resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = ListingCategoryForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('litecms.property.modules'), 'property', guard_url('property'));
            return $next($request);
        });
    }

    /**
     * Display a list of listing_category.
     *
     * @return Response
     */
    public function index(ListingCategoryResourceRequest $request)
    {
        $request = $request->all();
        $page = ListingCategoryActions::run('paginate', $request);

        $data = new ListingCategoriesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('property::listing_category.names'))
            ->view('property::listing_category.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display listing_category.
     *
     * @param Request $request
     * @param Model   $listing_category
     *
     * @return Response
     */
    public function show(ListingCategoryResourceRequest $request, ListingCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ListingCategoryResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('property::listing_category.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('property::listing_category.show')
            ->output();
    }

    /**
     * Show the form for creating a new listing_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ListingCategoryResourceRequest $request, ListingCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ListingCategoryResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('property::listing_category.name'))
            ->view('property::listing_category.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new listing_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ListingCategoryResourceRequest $request, ListingCategory $model)
    {
        try {
            $request = $request->all();
            $model = ListingCategoryAction::run('store', $model, $request);
            $data = new ListingCategoryResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('property::listing_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('property/listing_category/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/property/listing_category'))
                ->redirect();
        }

    }

    /**
     * Show listing_category for editing.
     *
     * @param Request $request
     * @param Model   $listing_category
     *
     * @return Response
     */
    public function edit(ListingCategoryResourceRequest $request, ListingCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ListingCategoryResource($model);
        // return view('property::listing_category.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('property::listing_category.name'))
            ->view('property::listing_category.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the listing_category.
     *
     * @param Request $request
     * @param Model   $listing_category
     *
     * @return Response
     */
    public function update(ListingCategoryResourceRequest $request, ListingCategory $model)
    {
        try {
            $request = $request->all();
            $model = ListingCategoryAction::run('update', $model, $request);
            $data = new ListingCategoryResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('property::listing_category.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('property/listing_category/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/listing_category/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the listing_category.
     *
     * @param Model   $listing_category
     *
     * @return Response
     */
    public function destroy(ListingCategoryResourceRequest $request, ListingCategory $model)
    {
        try {

            $request = $request->all();
            $model = ListingCategoryAction::run('destroy', $model, $request);
            $data = new ListingCategoryResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('property::listing_category.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('property/listing_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/listing_category/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
