<?php

namespace Litecms\Property\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Property\Actions\PropertyAction;
use Litecms\Property\Http\Requests\PropertyActionRequest;
use Litecms\Property\Http\Resources\PropertyResource;
use Litecms\Property\Models\Property;

/**
 * Admin web controller class.
 */
class PropertyActionController extends BaseController
{

    /**
     * Action controller function for property.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PropertyActionRequest $request, Property $property, $action)
    {
        try {
            $request = $request->all();
            $property = PropertyAction::run($action, $property, $request);

            $data = new PropertyResource($property);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('property::property.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('property/property/' . $property->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/property/' . $property->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
