<?php

namespace Litecms\Property\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Property\Actions\PropertyExim;
use Litecms\Property\Http\Requests\PropertyEximRequest;

/**
 * Admin web controller class.
 */
class PropertyEximController extends BaseController
{
    /**
     * Action controller function for property.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PropertyEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = PropertyExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('property:property.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('property/property/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/property/' . $exim))
                ->redirect();
        }
    }
}
