<?php

namespace Litecms\Property\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Property\Events\ListingCategoryAction as ListingCategoryActionEvent;
use Litecms\Property\Notifications\ListingCategoryAction as ListingCategoryActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ListingCategoryAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ListingCategoryActionEvent.
     *
     * @param   ListingCategoryActionEvent  $event
     * @return mixed
     */
    public function handle(ListingCategoryActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $listing_category.
     *
     * @param   ListingCategoryActionEvent  $event
     * @return void
     */
    public function create(ListingCategoryActionEvent $event)
    {
        $client = $event->listing_category->client;
        Notification::send($client, new ListingCategoryActionNotification($event));
    }

    /**
     * Handle the ListingCategoryActionEvent as a listener.
     *
     * @param   ListingCategoryActionEvent  $event
     * @return mixed
     */
    public function asListener(ListingCategoryActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ListingCategoryActionEvent  $event
     * @return bool
     */
    private function isAllowed(ListingCategoryActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
