<?php

namespace Litecms\Property\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Property\Events\ListingCategoryWorkflow as ListingCategoryWorkflowEvent;
use Litecms\Property\Notifications\ListingCategoryWorkflow as ListingCategoryWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ListingCategoryWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ListingCategoryWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $listing_category is submitted.
     *
     * @param ListingCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ListingCategoryWorkflowEvent $event)
    {
        $client = $event->listing_category->client;
        Notification::send($client, new ListingCategoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $listing_category is published.
     *
     * @param ListingCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ListingCategoryWorkflowEvent $event)
    {
        $client = $event->listing_category->client;
        Notification::send($client, new ListingCategoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $listing_category is approved.
     *
     * @param ListingCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ListingCategoryWorkflowEvent $event)
    {
        $client = $event->listing_category->client;
        Notification::send($client, new ListingCategoryWorkflowNotification($event));
    }

    /**
     * Handles the $listing_category workflow event as a listener.
     *
     * @param ListingCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ListingCategoryWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
