<?php
namespace Litecms\Property\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Property\Events\ListingCategoryAction as ListingCategoryActionEvent;
use Litecms\Property\Models\ListingCategory;

class ListingCategoryAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $listing_category;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ListingCategoryActionEvent $listing_category
     */
    public function __construct(ListingCategoryActionEvent $listing_category)
    {
        $this->action = $event->action;
        $this->listing_category = $listing_category;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('ListingCategory Approved - ' . config('app.name'))
            ->view('property::listing_category.email.action', ['data' => $this->listing_category]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
