<?php

namespace Litecms\Property\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Property\Models\ListingCategory;

class ListingCategoryPolicy
{

    use ListingCategoryAction;

    /**
     * Determine if the given user can view the listing_category.
     *
     * @param UserPolicyInterface $authUser
     * @param ListingCategory $listing_category
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, ListingCategory $listing_category)
    {
        if ($authUser->canDo('property.listing_category.view') && $authUser->isAdmin()) {
            return true;
        }

        return $listing_category->user_id == user_id() && $listing_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a listing_category.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('property.listing_category.create');
    }

    /**
     * Determine if the given user can update the given listing_category.
     *
     * @param UserPolicyInterface $authUser
     * @param ListingCategory $listing_category
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, ListingCategory $listing_category)
    {
        if ($authUser->canDo('property.listing_category.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $listing_category->user_id == user_id() && $listing_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given listing_category.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, ListingCategory $listing_category)
    {
        return $listing_category->user_id == user_id() && $listing_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given listing_category.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, ListingCategory $listing_category)
    {
        if ($authUser->canDo('property.listing_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given listing_category.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, ListingCategory $listing_category)
    {
        if ($authUser->canDo('property.listing_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
