<?php

namespace Litecms\Property\Policies;

use Litecms\Property\Models\Property;
use Litepie\User\Interfaces\UserPolicyInterface;

trait PropertyAction
{

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('property.property.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Property $property) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('property.property.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('property.property.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Property $property)
    {


        if ($authUser->canDo('property.property.action.delete')) {
            return true;
        }

        return false;
    }


}
