<?php

namespace Litecms\Property\Policies;

use Litecms\Property\Models\Property;
use Litepie\User\Interfaces\UserPolicyInterface;

trait PropertyWorkflow
{

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function submit(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function publish(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unpublish(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function archive(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unarchive(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function reject(UserPolicyInterface $authUser, Property $property)
    {
        if ($authUser->canDo('property.property.reject')) {
            return true;
        }

        return false;
    }

}
